bpack package
=============

.. automodule:: bpack
   :members:
   :undoc-members:
   :show-inheritance:

.. only:: html

   Submodules
   ----------

.. toctree::
   :maxdepth: 4

   bpack.ba
   bpack.bs
   bpack.codecs
   bpack.descriptors
   bpack.enums
   bpack.np
   bpack.st
   bpack.typing
   bpack.utils
